@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2012 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -876,7 +876,7 @@ sign_in_identity (GoaKerberosIdentityManager *self,
                                       &error))
     {
       if (is_new_identity)
-        goa_kerberos_identity_erase (identity, NULL);
+        goa_kerberos_identity_erase (GOA_KERBEROS_IDENTITY (identity), NULL);
 
       g_simple_async_result_set_from_error (operation->result, error);
       g_simple_async_result_set_op_res_gpointer (operation->result,
@@ -1108,7 +1108,7 @@ goa_kerberos_identity_manager_get_identity_finish (GoaIdentityManager  *self,
   identity =
     g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result));
 
-  return identity;
+  return g_object_ref (identity);
 }
 
 static void
